package com.bonus.canteen.core.kitchen.mapper;

import java.util.List;
import com.bonus.canteen.core.kitchen.domain.KitchenWasteMeal;

/**
 * 厨房餐余浪费Mapper接口
 *
 * @author xsheng
 * @date 2025-06-16
 */
public interface KitchenWasteMealMapper {
    /**
     * 查询厨房餐余浪费
     *
     * @param ledgerId 厨房餐余浪费主键
     * @return 厨房餐余浪费
     */
    public KitchenWasteMeal selectKitchenWasteMealByLedgerId(Long ledgerId);

    /**
     * 查询厨房餐余浪费列表
     *
     * @param kitchenWasteMeal 厨房餐余浪费
     * @return 厨房餐余浪费集合
     */
    public List<KitchenWasteMeal> selectKitchenWasteMealList(KitchenWasteMeal kitchenWasteMeal);

    /**
     * 新增厨房餐余浪费
     *
     * @param kitchenWasteMeal 厨房餐余浪费
     * @return 结果
     */
    public int insertKitchenWasteMeal(KitchenWasteMeal kitchenWasteMeal);

    /**
     * 修改厨房餐余浪费
     *
     * @param kitchenWasteMeal 厨房餐余浪费
     * @return 结果
     */
    public int updateKitchenWasteMeal(KitchenWasteMeal kitchenWasteMeal);

    /**
     * 删除厨房餐余浪费
     *
     * @param ledgerId 厨房餐余浪费主键
     * @return 结果
     */
    public int deleteKitchenWasteMealByLedgerId(Long ledgerId);

    /**
     * 批量删除厨房餐余浪费
     *
     * @param ledgerIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKitchenWasteMealByLedgerIds(Long[] ledgerIds);

    /**
     * 查询厨房餐余浪费汇总
     *
     * @param kitchenWasteMeal 厨房餐余浪费
     * @return 厨房餐余浪费集合
     */
    public List<KitchenWasteMeal> selectKitchenWasteMealListCount(KitchenWasteMeal kitchenWasteMeal);
}
