package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenWasteMeal;
import com.bonus.canteen.core.kitchen.service.IKitchenWasteMealService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房餐余浪费Controller
 * 
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "厨房餐余浪费接口")
@RestController
@RequestMapping("/kitchen_waste_meal")
public class KitchenWasteMealController extends BaseController {
    @Autowired
    private IKitchenWasteMealService kitchenWasteMealService;

    /**
     * 查询厨房餐余浪费列表
     */
    @ApiOperation(value = "查询厨房餐余浪费列表")
    //@RequiresPermissions("kitchen:meal:list")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody @Valid KitchenWasteMeal kitchenWasteMeal) {
        startPage();
        List<KitchenWasteMeal> list = kitchenWasteMealService.selectKitchenWasteMealList(kitchenWasteMeal);
        return getDataTable(list);
    }

    /**
     * 查询厨房餐余浪费汇总
     */
    @ApiOperation(value = "查询厨房餐余浪费汇总")
    //@RequiresPermissions("kitchen:meal:list")
    @PostMapping("/list/count")
    public TableDataInfo listCount(@RequestBody @Valid KitchenWasteMeal kitchenWasteMeal) {
        startPage();
        List<KitchenWasteMeal> list = kitchenWasteMealService.selectKitchenWasteMealListCount(kitchenWasteMeal);
        return getDataTable(list);
    }

    /**
     * 导出厨房餐余浪费列表
     */
    @ApiOperation(value = "导出厨房餐余浪费列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:meal:export")
    @SysLog(title = "厨房餐余浪费", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出厨房餐余浪费")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenWasteMeal kitchenWasteMeal) {
        List<KitchenWasteMeal> list = kitchenWasteMealService.selectKitchenWasteMealList(kitchenWasteMeal);
        ExcelUtil<KitchenWasteMeal> util = new ExcelUtil<KitchenWasteMeal>(KitchenWasteMeal.class);
        util.exportExcel(response, list, "厨房餐余浪费数据");
    }

    /**
     * 获取厨房餐余浪费详细信息
     */
    @ApiOperation(value = "获取厨房餐余浪费详细信息")
    //@RequiresPermissions("kitchen:meal:query")
    @GetMapping(value = "/{ledgerId}")
    public AjaxResult getInfo(@PathVariable("ledgerId") Long ledgerId) {
        return success(kitchenWasteMealService.selectKitchenWasteMealByLedgerId(ledgerId));
    }

    /**
     * 新增厨房餐余浪费
     */
    @ApiOperation(value = "新增厨房餐余浪费")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:meal:add")
    @SysLog(title = "厨房餐余浪费", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增厨房餐余浪费")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenWasteMeal kitchenWasteMeal) {
        try {
            return toAjax(kitchenWasteMealService.insertKitchenWasteMeal(kitchenWasteMeal));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房餐余浪费
     */
    @ApiOperation(value = "修改厨房餐余浪费")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:meal:edit")
    @SysLog(title = "厨房餐余浪费", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改厨房餐余浪费")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenWasteMeal kitchenWasteMeal) {
        try {
            return toAjax(kitchenWasteMealService.updateKitchenWasteMeal(kitchenWasteMeal));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除厨房餐余浪费
     */
    @ApiOperation(value = "删除厨房餐余浪费")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:meal:remove")
    @SysLog(title = "厨房餐余浪费", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除厨房餐余浪费")
	@PostMapping("/del/{ledgerIds}")
    public AjaxResult remove(@PathVariable Long[] ledgerIds) {
        return toAjax(kitchenWasteMealService.deleteKitchenWasteMealByLedgerIds(ledgerIds));
    }
}
